### Name: rfe
### Title: Backwards Feature Selection
### Aliases: rfe rfe.default rfeIter
### Keywords: models

### ** Examples

## Not run: 
##D data(BloodBrain)
##D 
##D x <- scale(bbbDescr[,-nearZeroVar(bbbDescr)])
##D x <- x[, -findCorrelation(cor(x), .8)]
##D x <- as.data.frame(x)
##D 
##D set.seed(1)
##D lmProfile <- rfe(x, logBBB,
##D                  sizes = c(2:25, 30, 35, 40, 45, 50, 55, 60, 65),
##D                  rfeControl = rfeControl(functions = lmFuncs, 
##D                                          number = 200))
##D set.seed(1)
##D lmProfile2 <- rfe(x, logBBB,
##D                  sizes = c(2:25, 30, 35, 40, 45, 50, 55, 60, 65),
##D                  rfeControl = rfeControl(functions = lmFuncs, 
##D                                          rerank = TRUE, 
##D                                          number = 200))
##D 
##D xyplot(lmProfile$results$RMSE + lmProfile2$results$RMSE +
##D        rfProfile$results$RMSE + rfProfile2$results$RMSE ~ 
##D        lmProfile$results$Variables, 
##D        type = c("g", "p", "l"), 
##D        auto.key = TRUE)
##D 
##D rfProfile <- rfe(x, logBBB,
##D                  sizes = c(2, 5, 10, 20),
##D                  rfeControl = rfeControl(functions = rfFuncs))
##D 
##D bagProfile <- rfe(x, logBBB,
##D                   sizes = c(2, 5, 10, 20),
##D                   rfeControl = rfeControl(functions = treebagFuncs))
##D 
##D set.seed(1)
##D svmProfile <- rfe(x, logBBB,
##D                   sizes = c(5, 20, 65),
##D                   rfeControl = rfeControl(functions = caretFuncs, 
##D                                           number = 200),
##D                   ## pass options to train()
##D                   method = "svmRadial",
##D                   fit = FALSE)
##D 
##D ## classification with no resampling
##D 
##D data(mdrr)
##D mdrrDescr <- scale(mdrrDescr[,-nearZeroVar(mdrrDescr)])
##D mdrrDescr <- mdrrDescr[, -findCorrelation(cor(mdrrDescr), .8)]
##D 
##D set.seed(1)
##D inTrain <- createDataPartition(mdrrClass, p = .75, list = FALSE)[,1]
##D 
##D train <- mdrrDescr[ inTrain, ]
##D test  <- mdrrDescr[-inTrain, ]
##D trainClass <- mdrrClass[ inTrain]
##D testClass  <- mdrrClass[-inTrain]
##D 
##D preProc <- preProcess(train)
##D train <- predict(preProc, train)
##D test  <- predict(preProc, test)
##D 
##D nbProfile <- rfeIter(train, trainClass,
##D                      test,  testClass, 
##D                      sizes = c(1:10, 15, 30),
##D                      rfeControl = rfeControl(functions = nbFuncs))
##D 
##D splitUp <- split(nbProfile$pred, 
##D                  factor(nbProfile$pred$subset))
##D testResults <- lapply(splitUp, 
##D                       function(u) postResample(u$pred, u$obs))
##D Variables <- as.numeric(names(testResults))
##D 
##D testResults <- do.call("rbind", testResults)
##D testResults <- cbind(testResults, Variables)
##D plot(testResults[,3], testResults[,1])
## End(Not run)

#######################################
## Parallel Processing Example via MPI

## Not run: 
##D 
##D ## A function to emulate lapply in parallel
##D mpiClacs <- function(X, FUN, ...)
##D   {
##D     theDots <- list(...)
##D     parLapply(theDots$cl, X, FUN)
##D   }
##D 
##D library(snow)
##D cl <- makeCluster(5, "MPI")
##D 
##D set.seed(1)
##D lmProfile <- rfe(x, logBBB,
##D                  sizes = c(2:25, 30, 35, 40, 45, 50, 55, 60, 65),
##D                  rfeControl = rfeControl(functions = lmFuncs, 
##D                                          number = 200,
##D                                          workers = 5,
##D                                          computeFunction = mpiClacs,
##D                                          computeArgs = list(cl = cl)))
##D 
##D stopCluster(cl)
## End(Not run)

#######################################
## Parallel Processing Example via NWS
## Not run: 
##D 
##D nwsClacs <- function(X, FUN, ...)
##D   {
##D     theDots <- list(...)
##D     eachElem(theDots$sObj,
##D              fun = FUN,
##D              elementArgs = list(X))
##D   }
##D 
##D library(nws)
##D sObj <- sleigh(workerCount = 5)
##D 
##D set.seed(1)
##D lmProfile <- rfe(x, logBBB,
##D                  sizes = c(2:25, 30, 35, 40, 45, 50, 55, 60, 65),
##D                  rfeControl = rfeControl(functions = lmFuncs, 
##D                                          number = 200,
##D                                          workers = 5,
##D                                          computeFunction = nwsClacs,
##D                                          computeArgs = list(sObj = sObj)))
##D close(sObj)
##D 
## End(Not run)



